// vim: set tabstop=4 shiftwidth=4 noexpandtab
/*
Gwenview - A simple image viewer for TDE
Copyright 2000-2004 Aurlien Gteau
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 2
 of the License, or (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

*/

#ifndef THREADGATE_H
#define THREADGATE_H

#include <tqobject.h>
#include <tqcolor.h>
namespace Gwenview {

class ThreadGate : public TQObject
{
Q_OBJECT
  
public:
	static ThreadGate* instance();
	TQColor color( const char* name );
private:
	ThreadGate();
signals:
	void signalColor( TQColor&, const char* );
private slots:
	void slotColor( TQColor&, const char* );
};

} // namespace
#endif

